﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using TMPro;
using UnityEngine.UI;
using UnityEngine.SceneManagement;
public class AniamteEnd : MonoBehaviour
{

    [SerializeField]
    private Graphic[] graphicsNail;

    [SerializeField]
    private Text nailText;
    [SerializeField]
    private Graphic[] graphicsScrew;
    [SerializeField]
    private Text screwText;


    [SerializeField]
    private float animateTime = 2.0f;

    [SerializeField]
    private float animateDelay = 1.0f;
    [SerializeField]
    private Graphic[] buttonGraphics;
    [SerializeField]
    private Graphic[] bg;

    [SerializeField]
    private Button replayButton;
    private bool canReplay = false;

    // Start is called before the first frame update
    void Start()
    {
        replayButton.enabled = false;
        SetAlpha(bg,0);
        SetAlpha(graphicsNail,0);
        SetAlpha(graphicsScrew,0);
        SetAlpha(buttonGraphics,0);
        StartCoroutine(Anim());   
        canReplay = false;
    }

    private IEnumerator Anim()
    {
        yield return StartCoroutine(FadeInGraphics(bg, animateTime, 0.627f));
        StartCoroutine(FadeInTextGraphics(graphicsNail,
                                          animateTime,
                                          nailText,
                                          GameController.instance.totalNails));
        yield return new WaitForSeconds(animateDelay);
        StartCoroutine(FadeInTextGraphics(graphicsScrew,
                                          animateTime,
                                          screwText,
                                          GameController.instance.totalScrews));
        yield return new WaitForSeconds(animateDelay);
        StartCoroutine(FadeInGraphics(buttonGraphics, animateTime));
        yield return new WaitForSeconds(animateDelay);
        canReplay = true;
    }

    private IEnumerator FadeInGraphics(Graphic[] graphics, float totalTime, float target = 1.0f)
    {
        
        float time = 0;
        while(time < totalTime)
        {
            time += Time.deltaTime;
    
            SetAlpha(graphics, time/totalTime*target);
            yield return new WaitForEndOfFrame();
        }
        SetAlpha(graphics, target);
    }

    private IEnumerator FadeInTextGraphics(Graphic[] graphics, 
        float totalTime, 
        Text text,
        float finalValue)
    {
        float increment = finalValue / totalTime;
        float time = 0;
        while(time < totalTime)
        {
            time += Time.deltaTime;
            float instant = (time/totalTime);
            text.text = "" + Mathf.RoundToInt(instant * totalTime * increment);
            SetAlpha(graphics, instant);
            yield return new WaitForEndOfFrame();
        }
        text.text = ""+finalValue;
        SetAlpha(graphics, 1.0f);
    }

    private void SetAlpha(Graphic[] graphics, float alpha)
    {
        foreach(Graphic graphic in graphics)
        {
            Color c = graphic.color;    
            c.a = alpha;
            graphic.color = c;
        }
    }

    public void Replay()
    {
        if(!canReplay)
        {
            return;
        }
        DetectStartGame.startOnAwake = true;

        SceneManager.LoadScene("GameScene");
    }

    public void Update()
    {
            if(!canReplay)
        {
            return;
        }

        if(Input.anyKeyDown)
        {
            Replay();
        }
    }
    

}
