﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using TMPro;

public class GameController : MonoBehaviour
{
    private int currentTarget;
    [SerializeField]
    private string[] targetText;
    [SerializeField]
    private string[] completeText;

    public bool HasStarted = false;

    [SerializeField]
    private TMP_FontAsset[] asset;

    [SerializeField]
    private Color[] targetColor;

    [SerializeField]
    private Color[] targetOutlineColor;

    [SerializeField]
    private TextMeshProUGUI text;

    [SerializeField]
    private Animation anim;
    
    public static GameController instance;
    private int currentState = 0;

    [SerializeField]
    private Clock clock;

    [SerializeField]
    private GameObject endCanvas;

    public int totalScrews = 0;
    public int totalNails = 0;

    private bool gameEnded = false;
    public bool GameEnded => gameEnded;

    // Start is called before the first frame update
    void Awake()
    {
        instance = this;

    }

    public void StartGame()
    {
        HasStarted = true;
        clock.StartGame();
        SetTarget(Random.Range(0,2));
        totalScrews = 0;
        totalNails = 0;
    }

    private void SetTarget(int target)
    {
        text.color = targetColor[target];
        text.text = targetText[target];
        text.outlineColor = targetOutlineColor[target];
        text.font = asset[target];
        currentTarget = target;
        
        anim.Rewind("moveText");
        anim.Play("moveText");
        anim.gameObject.SetActive(true);
    }

    public void NextState()
    {
        StartCoroutine(WinRoutine());
    }

    private IEnumerator WinRoutine()
    {
        text.text = completeText[currentState];

        anim.Rewind("moveText");
        anim.Play("moveText");
        anim.gameObject.SetActive(true);

        yield return new WaitForSeconds(10.0f);
        currentState = Random.Range(0,2);
        SetTarget(currentState);
    }

    public bool isCurrentTargetNail()
    {
        return currentTarget == 0;
    }

    public bool isCurrentTargetScrew()
    {
        return currentTarget == 1;
    }
    
    public void EndGame()
    {
        if(!gameEnded)
        {
            gameEnded = true;
            SetTarget(2);
            StartCoroutine(EndRoutine());
        }
    }

    private IEnumerator EndRoutine()
    {
        yield return new WaitForSeconds(2.0f);
        endCanvas.SetActive(true);
        yield return new WaitForSeconds(5.0f);
        anim.gameObject.SetActive(false);
    }

    public void Planted(bool isNail)
    {
        totalNails += isNail? 1 :0;
        totalScrews += isNail? 0 :1;
    }
}
